@@ -566,7 +566,6 @@ class WorkflowQuery:
 
     async def then(self, params):
         print(self.sbx_workflow.p(self.url))
-        print(params)
         async with aiohttp.ClientSession() as session:
             async with session.get(
                     self.sbx_workflow.p(self.url), params=params,
@@ -579,7 +578,6 @@ class WorkflowQuery:
         params['page'] = 0
         queries = []
         data = await self.then(params)
-        print(data)
         total_pages = math.ceil(data['totalCount']/page_size)
         for i in range(total_pages):
             params_aux = copy.deepcopy(params)
@@ -590,7 +588,7 @@ class WorkflowQuery:
         data = []
         for i in range(len(results)):
             for j in range(len(results[i])):
-                data.extend(results[i][j])
+                data.append(results[i][j])
         return data
 
 
